@@ -6,7 +6,7 @@ from .plot import (create_pie,
                    create_sunburst,
                    create_correlation_plot,
                    create_histogram)
-from .utils import (pie_sectors,
+from .utils import (columns_with_distinct_values,
                     extract_col_types,
                     figures_to_html)
 
@@ -41,6 +41,8 @@ class AutoPlot(object):
                  sunburst_path_limit=2,
                  correlation_method='pearson',
                  maximum_number_sectors=3,
+                 maximum_number_boxplots=5,
+                 maximum_number_violinplots=5,
                  pie_chart_hole=False,
                  create_html=True
                  ):
@@ -74,6 +76,7 @@ class AutoPlot(object):
         :param sunburst_path_limit:
         :param correlation_method: str, method to use to compute correlation
         :param maximum_number_sectors: int, maximum number of sectors in pie charts
+        :param maximum_number_boxplots:int, maximum_number_boxplots
         :param pie_chart_hole: boolean, whether to include a hole in pie chart or not
         :param create_html:
         """
@@ -106,9 +109,11 @@ class AutoPlot(object):
         self.sunburst_path_limit = sunburst_path_limit
         self.correlation_method = correlation_method
         self.maximum_number_sectors = maximum_number_sectors
+        self.maximum_number_boxplots = maximum_number_boxplots
+        self.maximum_number_violinplots = maximum_number_violinplots
         self.create_html = create_html
         self.pie_chart_hole = pie_chart_hole
-        self.pie_sectors = pie_sectors(df=self.df, maximum_number_sectors=self.maximum_number_sectors)
+        self.pie_sectors = columns_with_distinct_values(df=self.df, maximum_number_distinct_values=self.maximum_number_sectors)
 
     def chart_type(self):
         column_types = self.column_types
@@ -138,7 +143,7 @@ class AutoPlot(object):
 
         return chart_types
 
-    def plot(self):
+    def show(self):
         chart_types = self.chart_type()
 
         object_cols = self.column_types['object']
@@ -208,13 +213,14 @@ class AutoPlot(object):
 
                 if chart == 'boxplot' and self.include_box:
                     box_list = create_box(df=self.df,
+                                          maximum_number_boxplots=self.maximum_number_boxplots,
                                           col_types= self.column_types,
-                                            points=self.points,
-                                            boxmode=self.boxmode,
-                                            notched=self.notched,
-                                            color=None,
-                                            filename='box',
-                                            create_html=False)
+                                          points=self.points,
+                                          boxmode=self.boxmode,
+                                          notched=self.notched,
+                                          color=None,
+                                          filename='box',
+                                          create_html=False)
 
                     figure_list.extend(box_list)
 
@@ -239,11 +245,12 @@ class AutoPlot(object):
                 if chart == 'violinplot' and self.include_violin:
                     violin_list = create_violin(df=self.df,
                                                 col_types= self.column_types,
-                                                  filename='violin',
-                                                  create_html=False,
-                                                  points=self.violin_points,
-                                                  display_box=self.violin_box,
-                                                  color=None)
+                                                maximum_number_violinplots=self.maximum_number_violinplots,
+                                                filename='violin',
+                                                create_html=False,
+                                                points=self.violin_points,
+                                                display_box=self.violin_box,
+                                                color=None)
 
                     figure_list.extend(violin_list)
 
